@@ -4,6 +4,7 @@ from django import template
 from django.conf import settings
 from django.utils.text import slugify
 
+from badi_ticket.models import Ticket
 from badi_utils.date_calc import custom_change_date, gregorian_to_jalali
 from random import shuffle
 
@@ -152,8 +153,6 @@ def my_info(context):
     return {
         'unread_messages': Ticket.unread_messages_of(user),
         'amount': user.amount,
-        'posts': user.posts.count(),
-        'freeposters': user.freeposters.count(),
     }
 
 
@@ -170,50 +169,6 @@ def slugify_utf8(value):
     return slugify(value, True)
 
 
-@register.simple_tag(takes_context=True)
-def last_12_pages(context):
-    pages = list(Page.objects.all())
-    shuffle(pages)
-    return pages[:12]
-
-
-@register.simple_tag(takes_context=True)
-def last_breaking_news(context):
-    news = BlogNews.objects.filter(breaking_title__isnull=False)[:10]
-    return news
-
-
-@register.simple_tag(takes_context=True)
-def suggest_news(context):
-    news = BlogNews.objects.filter(is_recommend=True)[:4]
-    return news
-
-
-@register.simple_tag(takes_context=True)
-def categories(context):
-    cats = CategoryNews.objects.filter(index_show=True)
-    return cats
-
-
-@register.simple_tag(takes_context=True)
-def slider_news(context, count=7):
-    news = BlogNews.objects.filter(slider_title__isnull=False)[:count]
-    return news
-
-
-@register.simple_tag(takes_context=True)
-def week_top_news(context):
-    week_ago = datetime.datetime.now() - datetime.timedelta(days=8)
-    news = BlogNews.objects.filter(created_at__gt=week_ago).order_by('view')[:5]
-    return news
-
-
-@register.simple_tag(takes_context=True)
-def last_news(context, count=15):
-    news = BlogNews.objects.all()[:count]
-    return news
-
-
 @register.simple_tag(takes_context=True)
 def is_filled_profile(context):
     return context.request.user.is_filled_profile()
@@ -222,3 +177,45 @@ def is_filled_profile(context):
 @register.simple_tag()
 def get_text(index):
     return CONFIG_JSON.get(index) if CONFIG_JSON.get(index) else '---'
+
+
+@register.simple_tag(takes_context=True)
+def last_activities(context):
+    user = context.request.user
+    if user.is_authenticated:
+        return user.logs.all()[:10]
+    return []
+
+
+@register.filter()
+def get_log_icon(log):
+    if log.title == "Custom":
+        return "fa-info"
+    if log.title == "Login":
+        return "fa-arrow-down"
+    if log.title == "LogOut":
+        return "fa-arrow-up"
+    if log.title == "Insert":
+        return "fa-plus"
+    if log.title == "Edit":
+        return "fa-pen"
+    if log.title == "Remove":
+        return "fa-trash"
+    return 'fa-info'
+
+
+@register.filter()
+def get_log_color(log):
+    if log.title == "Custom":
+        return "info"
+    if log.title == "Login":
+        return "success"
+    if log.title == "LogOut":
+        return "info"
+    if log.title == "Insert":
+        return "primary"
+    if log.title == "Edit":
+        return "warning"
+    if log.title == "Remove":
+        return "danger"
+    return 'fa-info'
