@@ -3,9 +3,12 @@ from django.contrib.syndication.views import Feed
 from django.utils.feedgenerator import DefaultFeed
 from django.conf import settings
 
+if Site.objects.count() == 0:
+    Site(name='BadiDesign.ir', domain='BadiDesign.ir').save()
 CONFIG_JSON = getattr(settings, "CONFIG_JSON", {})
-site = Site.objects.filter(id=getattr(settings, "SITE_ID", None)).first() or 'BadiDesign.ir'
-SITE_URL = 'https://' + site.domain
+first = Site.objects.filter(id=getattr(settings, "SITE_ID", 1)).first()
+site = first.domain or 'BadiDesign.ir'
+SITE_URL = 'https://' + site
 
 
 class CorrectMimeTypeFeed(DefaultFeed):
